"""
Data sets, functions and scripts with examples to implement online estimation methods for the irregularly observed autoregressive (iAR) model (Eyheramendy et al.(2018) <doi:10.1093/mnras/sty2487>). The online learning algorithms implemented are: gradient descent (IAR_OGD), Newton-step (IAR-ONS) and Kalman filter recursions (IAR-OBR).  
https://github.com/felipeelorrieta/Onlineiar
"""

__version__ = '0.0.2'

from .methods import IAR_OBI,IAR_OBR,IAR_OGD,IAR_ONS,IARg_OGD,IARg_ONS,update_ONS,update_OGD
from .utils import IARPhi_sample



from setuptools import setup, find_packages
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

classifiers = [
    'Development Status :: 1 - Planning',
    'Intended Audience :: Developers',
    'Operating System :: Microsoft :: Windows :: Windows 11',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]

setup(
    name = 'iAROnline',
    version='0.0.2',
    description='Online estimation methods for the irregularly observed autoregressive (iAR) model',
    long_description='Data sets, functions and scripts with examples to implement online estimation methods for the irregularly observed autoregressive (iAR) model (Eyheramendy et al.(2018) <doi:10.1093/mnras/sty2487>). The online learning algorithms implemented are: gradient descent (IAR_OGD), Newton-step (IAR-ONS) and Kalman filter recursions (IAR-OBR).',
    url='https://github.com/felipeelorrieta/Onlineiar',
    author='Felipe Elorrieta',
    author_email='<felipe.elorrieta@usach.cl>',
    license='MIT',
    classifiers=classifiers,
    keywords = ['irregulary observed time series','autoregressive','online estimation methods'],
    packages=find_packages(),
    install_requires=['numpy','pandas','matplotlib','numba','iar','statistics'],
    package_dir={'iAROnline':'iAROnline'},
    package_data={"":["../data/*.csv"]},
    zip_safe=False)



import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import statistics
import iar
from numpy import linalg as LA
from numba import njit


@njit
def IARPhi_sample(phi, n, st):
    Sigma = np.zeros((n, n))
    for i in range(0, n):
        d = st[i] - st[i:n]
        Sigma[i, i:n] = phi[i]**abs(d)
        Sigma[i:n, i] = Sigma[i, i:n]
    val, vec = LA.eig(Sigma)
    A = np.matmul(np.matmul(vec, np.diag(np.sqrt(val))), np.transpose(vec))
    e = np.random.normal(size = n)
    y = np.dot(A,e)
    return y, st
